/**
 * @filter multiply,divide, plus, minus
 * @description 加减乘除运算
 * @example
 * ```
 * {{ 0.0023 | multiply(100) }} => 0.23
 * {{ 0.0023 | divide(0.0046) }} => 0.5
 * {{ 0.0023 | minus(0.0046) }} => -0.0023
 * {{ 0.0023 | plus(0.0046) }} => 0.0069
 * ```
 */
var operatorCom = require('../common/operator.js');
var operator = {};

['multiply','divide', 'plus', 'minus'].forEach(function(method) {
    operator[method] = function(a, b) {
        a = Number(a);
        b = Number(b);
        switch(method){
            case 'multiply':
                return operatorCom.floatMultiply(a,b);
            case 'divide':
                return operatorCom.floatDivide(a,b); 
            case 'plus':
                return operatorCom.floatAdd(a,b);
            case 'minus':
                return operatorCom.floatSub(a,b);
            // case 'mod':
            //     return a % b;  // 直接运算也出现精度问题 {{ 12.24 | mod(12)}} ==> 0.2400000000000002  
        }
    };
});

module.exports = operator;
